@@ -32,11 +32,27 @@ export type compressOptions = {
   minimumBitrate: number
 };
 
+export type format = 'base64' | 'JPEG';
+
+export type cropOptions = {
+  cropOffsetX: number,
+  cropOffsetY: number,
+  cropWidth: number,
+  cropHeight: number,
+
+  // TODO: TRIM IN CROP
+  // startTime: ?String,
+  // endTime: ?String,
+
+  quality: ?trimQuality
+};
+
 type processingCallback = Function;
 
 declare class RNVideoTrimmer {
   static trim(source: string, options: trimOptions, callback: processingCallback): void;
-  static getPreviewImageAtPosition(source: string, forSecond: number, maximumSize: previewMaxSize, callback: processingCallback): void;
-  static getAssetInfo(source: string, callback: processingCallback): void;
   static compress(source: string, options: compressOptions, callback: processingCallback): void;
+  static getAssetInfo(source: string, callback: processingCallback): void;
+  static getPreviewImageAtPosition(source: string, forSecond: number, maximumSize: previewMaxSize, callback: processingCallback): void;
+  static crop(source: string, options: cropOptions): Promise<{ source: string }>;
 }
