@@ -14,7 +14,7 @@ describe('[Utils]', () => {
 		});
 		it('using require(),  should return string', () => {
 			const returnValue = getActualSource(require('../../../test.jpeg'));
-			expect(returnValue).toMatch(/http:\/\//);
+			expect(returnValue).toMatch(/assets/);
 		});
 	});
 });
